@@ -44,7 +44,6 @@
 #include <QEvent>
 #include <QKeyEvent>
 
-#include <KActionCollection>
 #include "kpLogCategories.h"
 #include <KLocalizedString>
 
@@ -52,7 +51,6 @@
 #include "widgets/toolbars/kpColorToolBar.h"
 #include "kpDefs.h"
 #include "pixmapfx/kpPixmapFX.h"
-#include "tools/kpToolAction.h"
 #include "environments/tools/kpToolEnvironment.h"
 #include "widgets/toolbars/kpToolToolBar.h"
 #include "views/kpView.h"
